function ihb_PrepareClusterToView
%==================================================================================
% FORMAT ihb_PrepareClusterToView
%==================================================================================
% For saggital slices in the case when cluster intersects central
% plane only original cluster is drawn. If cluster completely contains
% in one hemisphere both original and symmetrical clusters are drawn
%==================================================================================
%   10.04.01    Sergey Pakhomov
%==================================================================================
%----------------------------------------------------------------------------------
% Get cluster cl to view
%----------------------------------------------------------------------------------
hFigMain = findobj('Type', 'figure', 'Tag', 'ihb_TalSpaceMain_fig');
clusters = getappdata(hFigMain, 'clusters');

hPopUp = findobj('Type', 'uicontrol', 'Style', 'popupmenu', 'Tag', 'ihb_ClusterPopUp');
indClusterToView = get(hPopUp, 'Value');
setappdata(hFigMain, 'indClusterToView', indClusterToView);

cl = clusters(indClusterToView);
%----------------------------------------------------------------------------------
% Get axis handles
%----------------------------------------------------------------------------------
hAxAxial = getappdata(hFigMain, 'hAxAxial');
hAxFront = getappdata(hFigMain, 'hAxFront');
hAxSagL = getappdata(hFigMain, 'hAxSagL');
hAxSagR = getappdata(hFigMain, 'hAxSagR');
%----------------------------------------------------------------------------------
% Get Talariach slices information (from ihb_TalSpaceDfl.mat)
%----------------------------------------------------------------------------------
dflFileName = ihb_FileFolderName('dfl');
load(dflFileName, 'ihbdfl_ax_info', 'ihbdfl_fr_info');
load(dflFileName, 'ihbdfl_sl_info', 'ihbdfl_sr_info');
load(dflFileName, 'ihbdfl_xLimD', 'ihbdfl_xLimI');
load(dflFileName, 'ihbdfl_yLimD', 'ihbdfl_yLimI');
load(dflFileName, 'ihbdfl_zLimD', 'ihbdfl_zLimI');
%----------------------------------------------------------------------------------
% Find indexes ranges for selected cluster
% drawSymLS ==  0 draw on left saggital only original cluster
%               1 draw on left saggital only symmetrical cluster
%----------------------------------------------------------------------------------
drawSymLS = 0; drawSymRS = 0;
rngAx = find([ihbdfl_ax_info(:).dist] > cl.zMin & [ihbdfl_ax_info(:).dist] < cl.zMax);
rngFr = find([ihbdfl_fr_info(:).dist] > cl.yMin & [ihbdfl_fr_info(:).dist] < cl.yMax);
rngSL = find([ihbdfl_sl_info(:).dist] > cl.xMin & [ihbdfl_sl_info(:).dist] < cl.xMax);
if isempty(rngSL)
    rngSL = find([ihbdfl_sl_info(:).dist] > -cl.xMax & [ihbdfl_sl_info(:).dist] < -cl.xMin);
    drawSymLS = 1;
end
rngSR = find([ihbdfl_sr_info(:).dist] > cl.xMin & [ihbdfl_sr_info(:).dist] < cl.xMax);
if isempty(rngSR)
    rngSR = find([ihbdfl_sr_info(:).dist] > -cl.xMax & [ihbdfl_sr_info(:).dist] < -cl.xMin);
    drawSymRS = 1;
end
%----------------------------------------------------------------------------------
% Save additional cluster data as application data for hFigMain
%----------------------------------------------------------------------------------
setappdata(hFigMain, 'drawSymLS', drawSymLS);
setappdata(hFigMain, 'drawSymRS', drawSymRS);
%----------------------------------------------------------------------------------
% Load all 4 slices
%----------------------------------------------------------------------------------
ihb_HideShowFigureAll('off');
hWait = waitbar(0,'Loading images. Please wait...');

index = floor((size(rngAx, 2)+1)/2);
ihb_LoadSlice(hFigMain, hAxAxial, ihbdfl_ax_info, rngAx, index, 'ax', ihbdfl_xLimD, ihbdfl_yLimI);
waitbar(0.2);

index = floor((size(rngFr, 2)+1)/2);
ihb_LoadSlice(hFigMain, hAxFront, ihbdfl_fr_info, rngFr, index, 'fr', ihbdfl_xLimD, ihbdfl_zLimI);
waitbar(0.4);

index = floor((size(rngSL, 2)+1)/2);
ihb_LoadSlice(hFigMain, hAxSagL, ihbdfl_sl_info, rngSL, index, 'sl', ihbdfl_yLimD, ihbdfl_zLimI);
waitbar(0.6);

index = floor((size(rngSR, 2)+1)/2);
ihb_LoadSlice(hFigMain, hAxSagR, ihbdfl_sr_info, rngSR, index, 'sr', ihbdfl_yLimD, ihbdfl_zLimI);
waitbar(0.8);
%----------------------------------------------------------------------------------
% Set UI information text
%----------------------------------------------------------------------------------
hStatic = findobj('Type', 'uicontrol', 'Tag', 'ihb_ClusterLevelProb');
set(hStatic, 'String', sprintf('%7.5f', cl.pClustLev));
hStatic = findobj('Type', 'uicontrol', 'Tag', 'ihb_VoxelLevelProb');
set(hStatic, 'String', sprintf('%7.5f', cl.pVoxelLev));
hStatic = findobj('Type', 'uicontrol', 'Tag', 'ihb_VolumeInVox');
set(hStatic, 'String', sprintf('%d', cl.numVox));
%----------------------------------------------------------------------------------
% Adjust 3D view
%----------------------------------------------------------------------------------
ihb_TalSpaceView3D('newCluster');
%----------------------------------------------------------------------------------
waitbar(1.0);
close(hWait);
ihb_HideShowFigureAll('on');
